@@ -9,11 +9,9 @@
 
 #include <QAbstractListModel>
 #include <QKeySequence>
-#include <QQmlPropertyMap>
 #include <QSortFilterProxyModel>
 #include <QtQml/qqmlregistration.h>
 
-#include <KLocalizedString>
 #include <KSharedConfig>
 
 using namespace Qt::StringLiterals;
@@ -64,6 +62,7 @@ public:
         DefaultShortcutRole,
         DescriptionRole,
         TypeRole,
+        SearchStringRole,
     };
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -95,7 +94,7 @@ Q_SIGNALS:
     void muteAction();
     void openContextMenuAction();
     void openFileAction();
-    void openSubtitlesFileAction();
+    void addExternalSubtitleAction();
     void openUrlAction();
     void playbackSpeedIncreaseAction();
     void playbackSpeedDecreaseAction();
