@@ -25,9 +25,10 @@
 #include "config-haruna.h"
 #include "database.h"
 #include "generalsettings.h"
-#include "global.h"
 #include "lockmanager.h"
+#include "miscutils.h"
 #include "mpvproperties.h"
+#include "pathutils.h"
 #include "playbacksettings.h"
 #include "playlistfilterproxymodel.h"
 #include "playlistmodel.h"
@@ -55,7 +56,6 @@ MpvItem::MpvItem(QQuickItem *parent)
     , m_subtitleTracksModel{std::make_unique<TracksModel>()}
     , m_playlists{std::make_unique<PlaylistMultiProxiesModel>()}
     , m_chaptersModel{std::make_unique<ChaptersModel>()}
-    , m_watchLaterPath{QString(Global::instance()->appConfigDirPath()).append(u"/watch-later/"_s)}
     , m_saveTimePositionTimer{std::make_unique<QTimer>()}
 {
     Q_EMIT observeProperty(MpvProperties::self()->MediaTitle, MPV_FORMAT_STRING);
@@ -105,7 +105,7 @@ MpvItem::MpvItem(QQuickItem *parent)
 
     // run user commands
     KSharedConfig::Ptr m_customPropsConfig;
-    QString ccConfig = Global::instance()->appConfigFilePath(Global::ConfigFile::CustomCommands);
+    QString ccConfig = PathUtils::instance()->configFilePath(PathUtils::ConfigFile::CustomCommands);
     m_customPropsConfig = KSharedConfig::openConfig(ccConfig, KConfig::SimpleConfig);
     QStringList groups = m_customPropsConfig->groupList();
     for (const QString &_group : std::as_const(groups)) {
@@ -144,7 +144,7 @@ void MpvItem::initProperties()
     }
     Q_EMIT setProperty(MpvProperties::self()->YtdlFormat, ytdlFormat);
 
-    Q_EMIT setProperty(MpvProperties::self()->SubtitleAuto, u"exact"_s);
+    Q_EMIT setProperty(MpvProperties::self()->SubtitleAuto, u"fuzzy"_s);
     Q_EMIT setProperty(MpvProperties::self()->SubtitleUseMargins, SubtitlesSettings::allowOnBlackBorders());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleAssForceMargins, SubtitlesSettings::allowOnBlackBorders());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleFont, SubtitlesSettings::fontFamily());
@@ -156,6 +156,10 @@ void MpvItem::initProperties()
     Q_EMIT setProperty(MpvProperties::self()->SubtitleBorderSize, SubtitlesSettings::borderSize());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleBold, SubtitlesSettings::isBold());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleItalic, SubtitlesSettings::isItalic());
+    Q_EMIT setProperty(MpvProperties::self()->ReplayGain, AudioSettings::replayGain());
+    Q_EMIT setProperty(MpvProperties::self()->ReplayGainClip, !AudioSettings::replayGainPreventClip());
+    Q_EMIT setProperty(MpvProperties::self()->ReplayGainPreamp, AudioSettings::replayGainPreamp());
+    Q_EMIT setProperty(MpvProperties::self()->ReplayGainFallback, AudioSettings::replayGainFallback());
 
     auto setSubPaths = [this]() {
         QString subFoldersString;
@@ -323,15 +327,15 @@ void MpvItem::onReady()
     setIsReady(true);
     auto proxyModel = m_playlists->defaultFilterProxy();
     QUrl url{Application::instance()->url(0)};
+    // set last session's active playlist as visible
+    m_playlists->setVisibleIndex(m_playlists->m_activeIndex);
     if (!url.isEmpty() && url.isValid()) {
         proxyModel->addItem(Application::instance()->url(0), PlaylistModel::Clear);
         Q_EMIT addToRecentFiles(url, RecentFilesModel::OpenedFrom::ExternalApp, url.fileName());
     } else {
         if (PlaybackSettings::openLastPlayedFile()) {
-            // Internal playlists are read at this point and active playlist is set. If an internal playlist
-            // is active, make it visible too and start playing.
             if (m_playlists->m_activeIndex != 0) {
-                m_playlists->setVisibleIndex(m_playlists->m_activeIndex);
+                // restore last session's playing item
                 activeFilterProxyModel()->setPlayingItem(activeFilterProxyModel()->playlistModel()->m_playingItem);
             } else {
                 // if both lastPlaylist and lastPlayedFile are set the playlist is loaded
@@ -359,7 +363,7 @@ void MpvItem::onEndFile(const QString &reason)
         const auto index = proxyModel->index(currentItem, 0);
         const auto title = proxyModel->data(index, PlaylistModel::TitleRole);
 
-        Q_EMIT Application::instance()->error(i18nc("@info:tooltip; %1 is a video title/filename", "Could not play: %1", title.toString()));
+        Q_EMIT MiscUtils::instance()->error(i18nc("@info:tooltip; %1 is a video title/filename", "Could not play: %1", title.toString()));
         return;
     }
 }
@@ -411,17 +415,17 @@ void MpvItem::onPropertyChanged(const QString &property, const QVariant &value)
 
     } else if (property == MpvProperties::self()->Position) {
         m_position = value.toDouble();
-        m_formattedPosition = Application::formatTime(m_position);
+        m_formattedPosition = MiscUtils::formatTime(m_position);
         Q_EMIT positionChanged();
 
     } else if (property == MpvProperties::self()->Remaining) {
         m_remaining = value.toDouble();
-        m_formattedRemaining = Application::formatTime(m_remaining);
+        m_formattedRemaining = MiscUtils::formatTime(m_remaining);
         Q_EMIT remainingChanged();
 
     } else if (property == MpvProperties::self()->Duration) {
         m_duration = value.toDouble();
-        m_formattedDuration = Application::formatTime(m_duration);
+        m_formattedDuration = MiscUtils::formatTime(m_duration);
         Q_EMIT durationChanged();
 
     } else if (property == MpvProperties::self()->Pause) {
@@ -500,7 +504,7 @@ void MpvItem::loadFile(const QString &file)
     if (url.isLocalFile() && !fi.exists()) {
         m_currentUrl = {};
         Q_EMIT currentUrlChanged();
-        Q_EMIT Application::instance()->error(i18nc("@info:tooltip; %1 is an absolute path", "File doesn't exist: %1", file));
+        Q_EMIT MiscUtils::instance()->error(i18nc("@info:tooltip; %1 is an absolute path", "File doesn't exist: %1", file));
         return;
     }
 
@@ -606,11 +610,11 @@ void MpvItem::onAsyncReply(const QVariant &data, mpv_event event)
         if (!data.toBool()) {
             // there's no video track
             // either because the file is an audio file or the video track can't be decoded
-            auto mimeType = Application::mimeType(currentUrl());
+            auto mimeType = MiscUtils::mimeType(currentUrl());
             if (mimeType.startsWith(u"video/"_s)) {
                 auto errMsg = i18nc("Error message when video can't be decoded/played",
                                     "No video track detected, most likely the video track can't be decoded/played due to missing codecs");
-                Q_EMIT Application::instance()->error(errMsg);
+                Q_EMIT MiscUtils::instance()->error(errMsg);
                 break;
             }
             Q_EMIT command(QStringList{u"video-add"_s, VideoSettings::defaultCover()});
@@ -666,7 +670,7 @@ double MpvItem::loadTimePosition()
     auto duration{item.duration};
 
     if (qFuzzyCompare(duration, 0.0)) {
-        QString mimeType = Application::mimeType(m_currentUrl);
+        QString mimeType = MiscUtils::mimeType(m_currentUrl);
         KFileMetaData::ExtractorCollection exCol;
         QList<KFileMetaData::Extractor *> extractors = exCol.fetchExtractors(mimeType);
         KFileMetaData::SimpleExtractionResult result(m_currentUrl.toLocalFile(), mimeType, KFileMetaData::ExtractionResult::ExtractMetaData);
@@ -691,13 +695,7 @@ double MpvItem::loadTimePosition()
 void MpvItem::resetTimePosition()
 {
     auto hash = md5(currentUrl().toString());
-    auto watchLaterConfig = QString(m_watchLaterPath).append(hash);
-    QFile f(watchLaterConfig);
-
-    if (f.exists()) {
-        f.remove();
-    }
-    f.close();
+    Database::instance()->deletePlaybackPosition(hash);
 }
 
 void MpvItem::userCommand(const QString &commandString)
