@@ -21,6 +21,7 @@ class MpvPreview : public MpvAbstractItem
     Q_PROPERTY(QString file READ file WRITE setFile NOTIFY fileChanged)
     Q_PROPERTY(bool accuratePreview READ accuratePreview WRITE setAccuratePreview NOTIFY accuratePreviewChanged)
     Q_PROPERTY(bool isLocalFile READ isLocalFile WRITE setIsLocalFile NOTIFY isLocalFileChanged)
+    Q_PROPERTY(bool isVideo READ isVideo WRITE setIsVideo NOTIFY isVideoChanged)
 
 public:
     MpvPreview();
@@ -41,6 +42,9 @@ public:
     bool isLocalFile() const;
     void setIsLocalFile(bool _isLocalFile);
 
+    bool isVideo() const;
+    void setIsVideo(bool _isVideo);
+
 Q_SIGNALS:
     void positionChanged();
     void aspectRatioChanged();
@@ -48,12 +52,15 @@ Q_SIGNALS:
     void accuratePreviewChanged();
     void isLocalFileChanged();
 
+    void isVideoChanged();
+
 private:
     double m_position{0.0};
     QString m_file;
     bool m_accuratePreview{false};
     bool m_isLocalFile{false};
     bool m_isReady{false};
+    bool m_isVideo{false};
 };
 
 #endif // MPVPREVIEW_H
